@@ -440,6 +440,7 @@ static drmModeConnector *_get_connector(int cfd, const char *connector_name)
 		     g_strcmp0(full_name, connector_name) == 0))
 			break;
 		drmModeFreeConnector(connector);
+		connector = NULL;
 	}
 	drmModeFreeResources(res);
 	return connector;
@@ -521,6 +522,11 @@ static void _setup_drm(struct _this *this)
 		_get_card_and_connector(this, this->connector_name);
 	if (connector == NULL)
 		g_error("DRM: Failed to find a connected connector.");
+
+	// We may become DRM master if we are the first process that opens DRM
+	// card, then drop DRM master so we could start compositor after ReFrame.
+	drmDropMaster(this->cfd);
+
 	if (this->connector_name == NULL)
 		this->connector_name = _get_connector_name(connector);
 	g_message("DRM: Found connected connector %s.", this->connector_name);
